@@ -10,7 +10,6 @@
 */
 
 #include "mainwindow.h"
-#include "aboutdialog.h"
 #include "iconsidepane.h"
 #include "prefs.h"
 #include "webengine/introductionwebenginepage.h"
@@ -41,7 +40,6 @@ using namespace Kontact;
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KParts/PartManager>
-#include <KPluginInfo>
 #include <KPluginMetaData>
 #include <KSharedConfig>
 #include <KShortcutsDialog>
@@ -118,7 +116,7 @@ void MainWindow::initGUI()
         Q_ASSERT(navigatorToolBar->sizeHint().isValid());
         navigatorToolBar->setMinimumWidth(navigatorToolBar->sizeHint().width());
     } else {
-        qCritical() << "Unable to find navigatorToolBar, probably kontactui.rc is missing";
+        qCCritical(KONTACT_LOG) << "Unable to find navigatorToolBar, probably kontactui.rc is missing";
     }
 }
 
@@ -756,19 +754,6 @@ void MainWindow::updateConfig()
     loadSettings();
 }
 
-void MainWindow::showAboutDialog()
-{
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-    if (!mAboutDialog) {
-        mAboutDialog = new AboutDialog(this);
-    }
-
-    mAboutDialog->show();
-    mAboutDialog->raise();
-    QApplication::restoreOverrideCursor();
-}
-
 void MainWindow::configureShortcuts()
 {
     KShortcutsDialog dialog(this);
@@ -940,7 +925,7 @@ QString MainWindow::showHideSideBarMessage(bool hidden) const
     if (hidden) {
         return i18nc("@info:status", "Sidebar is hidden. Show the sidebar again using the %1 key.", mShowHideAction->shortcut().toString());
     } else {
-        return QString();
+        return {};
     }
 }
 
